#!/usr/bin/env python

"""Tests for `AuDoLab` package."""

import pytest

from click.testing import CliRunner

import os
import sys
import numpy as np
import pandas as pd
sys.path.append(os.path.dirname(os.path.abspath(__file__)) + "/..")

from AuDoLab import cli
from AuDoLab import AuDoLab




@pytest.fixture
def response():
    """Sample pytest fixture.

    See more at: http://doc.pytest.org/en/latest/fixture.html
    """
    # import requests
    # return requests.get('https://github.com/audreyr/cookiecutter-pypackage')


def test_content(response):
    """Sample pytest test function with the pytest fixture as an argument."""
    # from bs4 import BeautifulSoup
    # assert 'GitHub' in BeautifulSoup(response.content).title.string


def test_command_line_interface():
    """Test the CLI."""
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0
    assert 'AuDoLab.cli.main' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help  Show this message and exit.' in help_result.output


# audo = AuDoLab.AuDoLab()
# # papers = audo.scrape_abstracts(
# #     keywords=["dentistry", "teeth", "tooth"],
# #     in_data="all_meta",
# #     pages=12,
# #     operator="or"
# # )
# papers_processed = audo.preprocessing(papers, "text")
# data_processed = audo.preprocessing(data, "transcription")
#
# data_tfidf, papers_tfidf = audo.tf_idf(
#     data, papers,"transcription", "text")
# classifier = audo.one_class_svm(papers_tfidf, data_tfidf)
# df_data = audo.choose_classifier(data_processed, classifier, 0)
# if __name__ == '__main__':
#     # lda = audo.lda_modeling(papers_processed)
#     # audo.lda_visualize_topics()
#     lda2 = audo.lda_modeling(df_data, no_above=0.3)
#     audo.lda_visualize_topics()



from AuDoLab.subclasses.preprocessing import Preprocessor
from sklearn.feature_extraction.text import CountVectorizer, TfidfVectorizer


class Tf_idf:
    """
    Beschreibung
    """

    def __init__(self):
        4 + 5

    @staticmethod
    def tfidf(
        data,
        papers,
        data_column="tokens",
        papers_column="tokens",
        features=None,
        ngrams=2,
    ):
        """[creates tf-idf objects for one-class SVM classification. The tf-idf scores are calculated over a joint corpus,
        however, the target data and the out-of-domain training data are stored in seperate, as the one-class SVM is only trained on
        the tf-idf scores of the out-of-domain training data]

        Args:
            data (DataFrame): [preprocessed target documents]
            papers (DataFrame): [preprocessed out-of-domain training data]
            data_colum (String): [name of columnin target dataframe where lemmatized documents are stored]. Defaults to 'lemma'
            papers_colum (String): [name of column in out-of-domain training dataframe where lemmatized documents are stored]. Defaults to 'lemma'
            ngrams (int, optional): [whether ngram are formed]. Defaults to 2.
            features (int, optional): [number of max features]. Defaults to 8000.

        Returns:
            [data and papers]: [tfidf object data for target data and ou-of-domain training data]
        """

        preprocessing = Preprocessor()
        df_temp = data.copy(deep=True)
        df_temp = Preprocessor.basic_preprocessing(df_temp, data_column)

        papers_temp = papers.copy(deep=True)
        papers_temp = Preprocessor.basic_preprocessing(papers_temp, papers_column)

        tfidf_vectorizer = TfidfVectorizer(
            ngram_range=(1, ngrams), max_features=features
        )

        corpus = df_temp['lemma'].tolist() +papers_temp['lemma'].tolist()
        tfidf_vectorizer.fit(corpus)

        data_corpus = df_temp['lemma'].tolist()
        paper_corpus = papers_temp['lemma'].tolist()

        data = tfidf_vectorizer.transform(data_corpus)
        papers = tfidf_vectorizer.transform(paper_corpus)

        return data, papers
